@@ -29,8 +29,10 @@ Azure AD OAuth2 backend, docs at:
 
 from __future__ import annotations
 
+import os
 import time
-from typing import Any
+from pathlib import Path
+from typing import Any, cast
 
 import jwt
 
@@ -111,7 +113,7 @@ class AzureADOAuth2(BaseOAuth2):
         try:
             decoded_id_token = jwt.decode(id_token, options={"verify_signature": False})
         except (jwt.DecodeError, jwt.ExpiredSignatureError) as de:
-            raise AuthTokenError(self, de)
+            raise AuthTokenError(self, de) from de
         return decoded_id_token
 
     def auth_extra_arguments(self):
@@ -138,14 +140,28 @@ class AzureADOAuth2(BaseOAuth2):
         return data
 
     def refresh_token_params(self, token, *args, **kwargs):
-        return {
+        client_secret = cast("str | None", self.setting("SECRET"))
+        params = {
             "client_id": self.setting("KEY"),
-            "client_secret": self.setting("SECRET"),
             "refresh_token": token,
             "grant_type": "refresh_token",
             "resource": self.setting("RESOURCE"),
         }
 
+        if client_secret:
+            params["client_secret"] = client_secret
+            return params
+
+        assertion = self.client_assertion(required=True)
+        params.update(
+            {
+                "client_assertion_type": self.client_assertion_type(),
+                "client_assertion": assertion,
+            }
+        )
+
+        return params
+
     def get_auth_token(self, user_id):
         """Return the access token for the given user, after ensuring that it
         has not expired, or refreshing it if so."""
@@ -157,6 +173,63 @@ class AzureADOAuth2(BaseOAuth2):
             access_token = new_token_response["access_token"]
         return access_token
 
+    def auth_complete_params(self, state=None):
+        params = super().auth_complete_params(state)
+        if params.get("client_secret"):
+            return params
+
+        assertion = self.client_assertion(required=True)
+        params.update(
+            {
+                "client_assertion_type": self.client_assertion_type(),
+                "client_assertion": assertion,
+            }
+        )
+        return params
+
+    def client_assertion(self, *, required: bool = False) -> str | None:
+        if cast("str | None", self.setting("SECRET")):
+            return None
+
+        assertion = self.setting("CLIENT_ASSERTION")
+        if assertion:
+            return assertion
+
+        token_path = (
+            os.environ.get(
+                "OAUTH2_FEDERATED_TOKEN_FILE"
+            )  # supports OAUTH2_ naming convention
+            or os.environ.get("AZURE_FEDERATED_TOKEN_FILE")  # canonical name
+            or self.setting("FEDERATED_TOKEN_FILE")
+        )
+        if not token_path:
+            if required:
+                raise AuthMissingParameter(self, "client_assertion")
+            return None
+
+        try:
+            assertion = Path(token_path).read_text(encoding="utf-8").strip()
+        except OSError as error:
+            if required:
+                raise AuthMissingParameter(self, "client_assertion") from error
+            return None
+
+        if not assertion:
+            if required:
+                raise AuthMissingParameter(self, "client_assertion")
+            return None
+
+        return assertion
+
+    def client_assertion_type(self) -> str:
+        return cast(
+            "str",
+            self.setting(
+                "CLIENT_ASSERTION_TYPE",
+                "urn:ietf:params:oauth:client-assertion-type:jwt-bearer",
+            ),
+        )
+
 
 class AzureADOAuth2V2(AzureADOAuth2):
     """Version of the AzureADOAuth2 backend that uses the v2.0 API endpoints,
