@@ -1,15 +1,3 @@
-import base64
-from typing import Any
-
-from cryptography.hazmat.backends import default_backend
-from cryptography.x509 import load_der_x509_certificate
-from jwt import DecodeError, ExpiredSignatureError, get_unverified_header
-from jwt import decode as jwt_decode
-
-from social_core.exceptions import AuthTokenError
-
-from .azuread import AzureADOAuth2
-
 """
 Copyright (c) 2015 Microsoft Open Technologies, Inc.
 
@@ -34,9 +22,7 @@ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
-"""
 
-"""
 Azure AD OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/azuread.html
 
@@ -44,6 +30,23 @@ See https://nicksnettravels.builttoroam.com/post/2017/01/24/Verifying-Azure-Acti
 for verifying JWT tokens.
 """
 
+from __future__ import annotations
+
+import base64
+from typing import TYPE_CHECKING, Any, cast
+
+from cryptography.x509 import load_der_x509_certificate
+from jwt import DecodeError, ExpiredSignatureError, get_unverified_header
+from jwt import decode as jwt_decode
+
+from social_core.exceptions import AuthTokenError
+
+from .azuread import AzureADOAuth2
+
+if TYPE_CHECKING:
+    from cryptography.hazmat.primitives.asymmetric.rsa import RSAPublicKey
+    from cryptography.x509 import Certificate
+
 
 class AzureADTenantOAuth2(AzureADOAuth2):
     name = "azuread-tenant-oauth2"
@@ -51,8 +54,8 @@ class AzureADTenantOAuth2(AzureADOAuth2):
     JWKS_URL = "{base_url}/discovery/keys{appid}"
 
     @property
-    def tenant_id(self):
-        return self.setting("TENANT_ID", "common")
+    def tenant_id(self) -> str:
+        return cast("str", self.setting("TENANT_ID", "common"))
 
     def openid_configuration_url(self):
         return self.OPENID_CONFIGURATION_URL.format(
@@ -67,7 +70,7 @@ class AzureADTenantOAuth2(AzureADOAuth2):
             f"?appid={self.setting('KEY')}" if self.setting("KEY") is not None else ""
         )
 
-    def get_certificate(self, kid):
+    def get_certificate(self, kid: str) -> Certificate:
         # retrieve keys from jwks_url
         resp = self.request(self.jwks_url(), method="GET")
         resp.raise_for_status()
@@ -80,7 +83,7 @@ class AzureADTenantOAuth2(AzureADOAuth2):
         else:
             raise DecodeError(f"Cannot find kid={kid}")
 
-        return load_der_x509_certificate(base64.b64decode(x5c), default_backend())
+        return load_der_x509_certificate(base64.b64decode(x5c))
 
     def get_user_id(self, details, response):
         """Use subject (sub) claim as unique id."""
@@ -102,12 +105,12 @@ class AzureADTenantOAuth2(AzureADOAuth2):
 
             return jwt_decode(
                 id_token,
-                key=certificate.public_key(),  # type: ignore[reportArgumentType]
+                key=cast("RSAPublicKey", certificate.public_key()),
                 algorithms=["RS256"],
                 audience=self.setting("KEY"),
             )
         except (DecodeError, ExpiredSignatureError) as error:
-            raise AuthTokenError(self, error)
+            raise AuthTokenError(self, error) from error
 
 
 class AzureADV2TenantOAuth2(AzureADTenantOAuth2):
