@@ -42,5 +42,5 @@ class CodingOAuth2(BaseOAuth2):
         return data.get("data")
 
     def _user_data(self, access_token, path=None):
-        url = urljoin(self.api_url(), "account/current_user{}".format(path or ""))
+        url = urljoin(self.api_url(), f"account/current_user{path or ''}")
         return self.get_json(url, params={"access_token": access_token})
