@@ -58,7 +58,7 @@ class EvernoteOAuth(BaseOAuth1):
         except HTTPError as err:
             # Evernote returns a 401 error when AuthCanceled
             if err.response.status_code == 401:
-                raise AuthCanceled(self, response=err.response)
+                raise AuthCanceled(self, response=err.response) from err
             raise
 
     def extra_data(
