@@ -66,7 +66,7 @@ class GithubOAuth2(BaseOAuth2):
         return data
 
     def _user_data(self, access_token, path=None):
-        url = urljoin(self.api_url(), "user{}".format(path or ""))
+        url = urljoin(self.api_url(), f"user{path or ''}")
         return self.get_json(url, headers={"Authorization": f"token {access_token}"})
 
 
@@ -83,7 +83,9 @@ class GithubMemberOAuth2(GithubOAuth2):
             # if the user is a member of the organization, response code
             # will be 204, see http://bit.ly/ZS6vFl
             if err.response.status_code != 204:
-                raise AuthFailed(self, "User doesn't belong to the organization")
+                raise AuthFailed(
+                    self, "User doesn't belong to the organization"
+                ) from err
         return user_data
 
     def member_url(self, user_data):
@@ -99,9 +101,7 @@ class GithubOrganizationOAuth2(GithubMemberOAuth2):
     def member_url(self, user_data):
         return urljoin(
             self.api_url(),
-            "orgs/{org}/members/{username}".format(
-                org=self.setting("NAME"), username=user_data.get("login")
-            ),
+            f"orgs/{self.setting('NAME')}/members/{user_data.get('login')}",
         )
 
 
@@ -114,9 +114,7 @@ class GithubTeamOAuth2(GithubMemberOAuth2):
     def member_url(self, user_data):
         return urljoin(
             self.api_url(),
-            "teams/{team_id}/members/{username}".format(
-                team_id=self.setting("ID"), username=user_data.get("login")
-            ),
+            f"teams/{self.setting('ID')}/members/{user_data.get('login')}",
         )
 
 
