@@ -28,4 +28,4 @@ class LiveJournalOpenId(OpenIdAuth):
         """Returns LiveJournal authentication URL"""
         if not self.data.get("openid_lj_user"):
             raise AuthMissingParameter(self, "openid_lj_user")
-        return "http://{}.livejournal.com".format(self.data["openid_lj_user"])
+        return f"http://{self.data['openid_lj_user']}.livejournal.com"
