@@ -30,5 +30,5 @@ class MailChimpOAuth2(BaseOAuth2):
     def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data and datacenter information from service"""
         return self.get_json(
-            self.METADATA_URL, headers={"Authorization": "OAuth " + access_token}
+            self.METADATA_URL, headers={"Authorization": f"OAuth {access_token}"}
         )
