@@ -2,9 +2,9 @@ from __future__ import annotations
 
 import base64
 import datetime
-import json
 from calendar import timegm
-from typing import TYPE_CHECKING, Any, Literal
+from json import loads
+from typing import TYPE_CHECKING, Any, Literal, cast
 
 import jwt
 from cryptography.hazmat.backends import default_backend
@@ -28,8 +28,11 @@ from social_core.utils import cache
 if TYPE_CHECKING:
     from collections.abc import Mapping
 
+    from jwt.types import Options
     from requests.auth import AuthBase
 
+    from social_core.strategy import BaseStrategy
+
 
 class OpenIdConnectAssociation:
     """Use Association model to save the nonce by force."""
@@ -66,7 +69,7 @@ class OpenIdConnectAuth(BaseOAuth2):
     ID_KEY = "sub"
     USERNAME_KEY = "preferred_username"
     JWT_ALGORITHMS = ["RS256"]
-    JWT_DECODE_OPTIONS: dict[str, Any] = {}
+    JWT_DECODE_OPTIONS: Options = {}
     JWT_LEEWAY: float = 1.0  # seconds
     VALIDATE_AT_HASH: bool = True
     CUSTOM_AT_HASH_ALGO: str | None = None
@@ -87,7 +90,9 @@ class OpenIdConnectAuth(BaseOAuth2):
     LOGIN_HINT = None
     ACR_VALUES = None
 
-    def __init__(self, strategy=None, redirect_uri: str | None = None) -> None:
+    def __init__(
+        self, strategy: BaseStrategy | None = None, redirect_uri: str | None = None
+    ) -> None:
         super().__init__(strategy, redirect_uri=redirect_uri)
         self.id_token = None
 
@@ -140,11 +145,11 @@ class OpenIdConnectAuth(BaseOAuth2):
         return not methods or "client_secret_basic" in methods
 
     def oidc_endpoint(self) -> str:
-        return self.setting("OIDC_ENDPOINT", self.OIDC_ENDPOINT)
+        return cast("str", self.setting("OIDC_ENDPOINT", self.OIDC_ENDPOINT))
 
     @cache(ttl=86400)
     def oidc_config(self) -> dict[Any, Any]:
-        return self.get_json(self.oidc_endpoint() + "/.well-known/openid-configuration")
+        return self.get_json(f"{self.oidc_endpoint()}/.well-known/openid-configuration")
 
     @cache(ttl=86400)
     def get_jwks_keys(self):
@@ -156,7 +161,7 @@ class OpenIdConnectAuth(BaseOAuth2):
 
     def get_remote_jwks_keys(self):
         response = self.request(self.jwks_uri())
-        return json.loads(response.text)["keys"]
+        return loads(response.text)["keys"]
 
     def auth_params(self, state=None):  # noqa: C901, PLR0912
         """Return extra arguments needed on auth process."""
@@ -239,7 +244,7 @@ class OpenIdConnectAuth(BaseOAuth2):
                 server_url=self.authorization_url(), handle=nonce
             )[0]
         except IndexError:
-            pass
+            return None
 
     def remove_nonce(self, nonce_id) -> None:
         self.strategy.storage.association.remove([nonce_id])
@@ -278,13 +283,15 @@ class OpenIdConnectAuth(BaseOAuth2):
                 # In case the key id is not found in the cached keys, just
                 # reload the JWKS keys. Ideally this should be done by
                 # invalidating the cache.
-                self.get_jwks_keys.invalidate()  # type: ignore[reportFunctionMemberAccess]
+                self.get_jwks_keys.invalidate()  # pyright: ignore[reportAttributeAccessIssue]
                 keys = self.get_jwks_keys()
 
         for key in keys:
             if kid is None or kid == key.get("kid"):
                 if "alg" not in key:
-                    key["alg"] = self.setting("JWT_ALGORITHMS", self.JWT_ALGORITHMS)[0]
+                    key["alg"] = cast(
+                        "list[str]", self.setting("JWT_ALGORITHMS", self.JWT_ALGORITHMS)
+                    )[0]
                 rsakey = jwt.PyJWK(key)
                 message, encoded_sig = id_token.rsplit(".", 1)
                 decoded_sig = base64url_decode(encoded_sig.encode("utf-8"))
@@ -316,17 +323,17 @@ class OpenIdConnectAuth(BaseOAuth2):
                 audience=client_id,
                 issuer=self.id_token_issuer(),
                 options=self.setting("JWT_DECODE_OPTIONS", self.JWT_DECODE_OPTIONS),
-                leeway=self.setting("JWT_LEEWAY", self.JWT_LEEWAY),
+                leeway=cast("int", self.setting("JWT_LEEWAY", self.JWT_LEEWAY)),
             )
-        except ExpiredSignatureError:
-            raise AuthTokenError(self, "Signature has expired")
-        except InvalidAudienceError:
+        except ExpiredSignatureError as error:
+            raise AuthTokenError(self, "Signature has expired") from error
+        except InvalidAudienceError as error:
             # compatibility with jose error message
-            raise AuthTokenError(self, "Token error: Invalid audience")
+            raise AuthTokenError(self, "Token error: Invalid audience") from error
         except InvalidTokenError as error:
-            raise AuthTokenError(self, str(error))
-        except PyJWTError:
-            raise AuthTokenError(self, "Invalid signature")
+            raise AuthTokenError(self, str(error)) from error
+        except PyJWTError as error:
+            raise AuthTokenError(self, "Invalid signature") from error
 
         # pyjwt does not validate OIDC claims
         # see https://github.com/jpadilla/pyjwt/pull/296
@@ -342,7 +349,8 @@ class OpenIdConnectAuth(BaseOAuth2):
         url: str,
         method: Literal["GET", "POST", "DELETE"] = "GET",
         headers: Mapping[str, str | bytes] | None = None,
-        data: dict | bytes | str | None = None,
+        data: dict | None = None,
+        json: dict | None = None,
         auth: tuple[str, str] | AuthBase | None = None,
         params: dict | None = None,
     ) -> dict[Any, Any]:
@@ -351,7 +359,13 @@ class OpenIdConnectAuth(BaseOAuth2):
         store it (temporarily).
         """
         response = super().request_access_token(
-            url, method, headers, data, auth, params
+            url,
+            method=method,
+            headers=headers,
+            data=data,
+            json=json,
+            auth=auth,
+            params=params,
         )
         self.id_token = self.validate_and_return_id_token(
             response["id_token"], response["access_token"]
