@@ -19,7 +19,7 @@ class PhabricatorOAuth2(BaseOAuth2):
 
     def api_url(self, path):
         api_url = self.setting("API_URL") or self.API_URL
-        return "{}{}".format(api_url.rstrip("/"), path)
+        return f"{api_url.rstrip('/')}{path}"
 
     def authorization_url(self):
         return self.api_url("/oauthserver/auth/")
