@@ -38,5 +38,5 @@ class ReadabilityOAuth(BaseOAuth1):
 
     def user_data(self, access_token: dict, *args, **kwargs) -> dict[str, Any] | None:
         return self.get_json(
-            READABILITY_API + "/users/_current", auth=self.oauth_auth(access_token)
+            f"{READABILITY_API}/users/_current", auth=self.oauth_auth(access_token)
         )
