@@ -4,6 +4,8 @@ Sketchfab OAuth2 backend, docs at:
     https://sketchfab.com/developers/oauth
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -31,7 +33,7 @@ class SketchfabOAuth2(BaseOAuth2):
             "email": email,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://sketchfab.com/v2/users/me",
