@@ -3,6 +3,8 @@ Stocktwits OAuth2 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/stocktwits.html
 """
 
+from typing import Any
+
 from .oauth import BaseOAuth2
 
 
@@ -35,7 +37,7 @@ class StocktwitsOAuth2(BaseOAuth2):
             "last_name": last_name,
         }
 
-    def user_data(self, access_token, *args, **kwargs):
+    def user_data(self, access_token: str, *args, **kwargs) -> dict[str, Any] | None:
         """Loads user data from service"""
         return self.get_json(
             "https://api.stocktwits.com/api/2/account/verify.json",
