@@ -3,7 +3,7 @@ Trello OAuth1 backend, docs at:
     https://python-social-auth.readthedocs.io/en/latest/backends/trello.html
 """
 
-from typing import Any
+from typing import Any, cast
 
 from .oauth import BaseOAuth1
 
@@ -42,9 +42,9 @@ class TrelloOAuth(BaseOAuth1):
         except ValueError:
             return None
 
-    def auth_extra_arguments(self):
+    def auth_extra_arguments(self) -> dict[str, str]:
         return {
-            "name": self.setting("APP_NAME", ""),
+            "name": cast("str", self.setting("APP_NAME", "")),
             # trello default expiration is '30days'
-            "expiration": self.setting("EXPIRATION", "never"),
+            "expiration": cast("str", self.setting("EXPIRATION", "never")),
         }
