@@ -15,7 +15,7 @@ class UntappdOAuth2(BaseOAuth2):
     AUTHORIZATION_URL = "https://untappd.com/oauth/authenticate/"
     ACCESS_TOKEN_URL = "https://untappd.com/oauth/authorize/"
     BASE_API_URL = "https://api.untappd.com"
-    USER_INFO_URL = BASE_API_URL + "/v4/user/info/"
+    USER_INFO_URL = f"{BASE_API_URL}/v4/user/info/"
     ACCESS_TOKEN_METHOD = "GET"
     STATE_PARAMETER = False
     REDIRECT_STATE = False
@@ -92,9 +92,7 @@ class UntappdOAuth2(BaseOAuth2):
                 "email": user_data.get("settings", {}).get("email_address", ""),
                 "first_name": user_data.get("first_name"),
                 "last_name": user_data.get("last_name"),
-                "fullname": " ".join(
-                    [user_data.get("first_name"), user_data.get("last_name")]
-                ),
+                "fullname": f"{user_data.get('first_name')} {user_data.get('last_name')}",
             }
         )
         return user_data
