@@ -32,11 +32,6 @@ class YahooOAuth2(BaseOAuth2):
         ("token_type", "token_type"),
     ]
 
-    def get_user_names(self, first_name, last_name):  # type: ignore[reportIncompatibleMethodOverride]
-        if first_name or last_name:
-            return f"{first_name} {last_name}", first_name, last_name
-        return None, None, None
-
     def get_user_details(self, response):
         """
         Return user details from Yahoo Profile.
