@@ -25,10 +25,6 @@ class BaseModel:
         cls.NEXT_ID += 1
         return cls.NEXT_ID - 1
 
-    @classmethod
-    def get(cls, key) -> Self | None:
-        return cls.cache.get(key)
-
     @classmethod
     def reset_cache(cls) -> None:
         cls.cache = {}
@@ -75,6 +71,10 @@ class User(BaseModel, UserProtocol):
     def save(self) -> None:
         User.cache[self.username] = self
 
+    @classmethod
+    def get(cls, key) -> Self | None:
+        return cls.cache.get(key)
+
 
 class TestUserSocialAuth(UserMixin, BaseModel):
     __test__ = False
@@ -152,6 +152,7 @@ class TestUserSocialAuth(UserMixin, BaseModel):
         cls,
         user: User,
         provider: str | None = None,
+        # pylint: disable-next=redefined-builtin
         id: int | None = None,  # noqa: A002
     ):
         return [
@@ -168,6 +169,10 @@ class TestUserSocialAuth(UserMixin, BaseModel):
     def get_users_by_email(cls, email: str):
         return [user for user in User.cache.values() if user.email == email]
 
+    @classmethod
+    def get(cls, key) -> Self | None:
+        return cls.cache.get(key)
+
 
 class TestNonce(NonceMixin, BaseModel):
     __test__ = False
@@ -188,9 +193,7 @@ class TestNonce(NonceMixin, BaseModel):
         return nonce
 
     @classmethod
-    def get(  # type: ignore[override]
-        cls, server_url, salt
-    ):
+    def get(cls, server_url: str, salt: str):
         return TestNonce.cache[server_url]
 
     @classmethod
@@ -225,7 +228,7 @@ class TestAssociation(AssociationMixin, BaseModel):
         assoc.save()
 
     @classmethod
-    def get(  # type: ignore[override]
+    def get(
         cls: type[TestAssociation],
         server_url: str | None = None,
         handle: str | None = None,
@@ -259,6 +262,10 @@ class TestCode(CodeMixin, BaseModel):
                 return c
         return None
 
+    @classmethod
+    def get(cls, key) -> Self | None:
+        return cls.cache.get(key)
+
 
 class TestPartial(PartialMixin, BaseModel):
     __test__ = False
@@ -277,6 +284,10 @@ class TestPartial(PartialMixin, BaseModel):
     def destroy(cls, token) -> None:
         cls.cache.pop(token)
 
+    @classmethod
+    def get(cls, key) -> TestPartial | None:
+        return cls.cache.get(key)
+
 
 class TestStorage(BaseStorage):
     __test__ = False
